Commands

Enum Commands 

pub enum Commands {
Show 86 variants Fast { prompt: Vec<String>, }, Local { prompt: Vec<String>, }, Value { prompt: Vec<String>, }, Short { prompt: Vec<String>, }, Rewrite { prompt: Vec<String>, }, Reply { prompt: Vec<String>, }, Image { prompt: Vec<String>, }, Photo { prompt: Vec<String>, }, Say { prompt: Vec<String>, }, Transcribe { file: String, }, Ocr { file: String, }, GoogleOcr { file: String, }, Rename { files: Vec<String>, }, Changelog { commit_hash: String, }, Commit {}, Svg { prompt: Vec<String>, }, Edit {}, Config {}, SectionModels {}, All { prompt: Vec<String>, }, Google { model: String, prompt: Vec<String>, }, Gemini { prompt: Vec<String>, }, GeminiFlash { prompt: Vec<String>, }, GoogleImage { prompt: Vec<String>, }, Groq { model: String, prompt: Vec<String>, }, Llama3 { prompt: Vec<String>, }, Cerebras { model: String, prompt: Vec<String>, }, Deepseek { model: String, prompt: Vec<String>, }, Openai { model: String, prompt: Vec<String>, }, Gpt5 { prompt: Vec<String>, }, Gpt5Mini { prompt: Vec<String>, }, Gpt5Nano { prompt: Vec<String>, }, Gpt41 { prompt: Vec<String>, }, Gpt41Mini { prompt: Vec<String>, }, Gpt41Nano { prompt: Vec<String>, }, O1Pro { prompt: Vec<String>, }, Anthropic { model: String, prompt: Vec<String>, }, ClaudeOpus { prompt: Vec<String>, }, ClaudeSonnet { prompt: Vec<String>, }, ClaudeHaiku { prompt: Vec<String>, }, Xai { model: String, prompt: Vec<String>, }, Grok { prompt: Vec<String>, }, Perplexity { model: String, prompt: Vec<String>, }, Sonar { prompt: Vec<String>, }, SonarPro { prompt: Vec<String>, }, SonarReasoning { prompt: Vec<String>, }, SonarReasoningPro { prompt: Vec<String>, }, SonarDeepResearch { prompt: Vec<String>, }, Llamafile { prompt: Vec<String>, }, Ollama { model: String, prompt: Vec<String>, }, SectionCoding {}, Bash { prompt: Vec<String>, }, C { prompt: Vec<String>, }, Cpp { prompt: Vec<String>, }, Cs { prompt: Vec<String>, }, Docker { prompt: Vec<String>, }, Elm { prompt: Vec<String>, }, Fish { prompt: Vec<String>, }, Fs { prompt: Vec<String>, }, Gd { prompt: Vec<String>, }, Git { prompt: Vec<String>, }, Gl { prompt: Vec<String>, }, Golang { prompt: Vec<String>, }, Hs { prompt: Vec<String>, }, Java { prompt: Vec<String>, }, Js { prompt: Vec<String>, }, Kt { prompt: Vec<String>, }, Ly { prompt: Vec<String>, }, Lua { prompt: Vec<String>, }, Nix { prompt: Vec<String>, }, Oc { prompt: Vec<String>, }, Php { prompt: Vec<String>, }, Pg { prompt: Vec<String>, }, Ps { prompt: Vec<String>, }, Py { prompt: Vec<String>, }, Rb { prompt: Vec<String>, }, Rs { prompt: Vec<String>, }, Sql { prompt: Vec<String>, }, Sw { prompt: Vec<String>, }, Ts { prompt: Vec<String>, }, Ty { prompt: Vec<String>, }, Wl { prompt: Vec<String>, }, Zig { prompt: Vec<String>, }, Jq { prompt: Vec<String>, }, SectionDatabase {}, Query { database: String, prompt: Vec<String>, },
}

Variants



Fast

Shortcut for groq openai/gpt-oss-20b

Fields

prompt: Vec<String>

The prompt to send to the AI model



Local

Shortcut for ollama llama3.2

Fields

prompt: Vec<String>

The prompt to send to the AI model



Value

Return only the value/answer without explanations

Fields

prompt: Vec<String>

The prompt to send to the AI model



Short

Answer the prompt in a short, compact, and focused manner

Fields

prompt: Vec<String>

The prompt to send to the AI model



Rewrite

Fix spelling, grammar, and wording issues in text passed via standard input

Fields

prompt: Vec<String>

Additional instructions for how to improve the text



Reply

Reply to a conversation passed via standard input. Add additional reply instructions as the prompt.

Fields

prompt: Vec<String>

How the AI should reply to the conversation



Image

Generate an image using GPT-image-1.5

Fields

prompt: Vec<String>

The prompt describing the image to generate



Photo

Generate a photorealistic image that looks like a camera photo

Fields

prompt: Vec<String>

The prompt describing the photo to generate



Say

Convert text to speech using OpenAI’s TTS model

Fields

prompt: Vec<String>

The text to convert to speech



Transcribe

Transcribe an audio file

Fields

file: String

The audio file to transcribe



Ocr

Extract text from an image

Fields

file: String

The file to extract text from



GoogleOcr

Extract text from an image using Google Gemini with high resolution

Fields

file: String

The file to extract text from



Rename

Analyze and rename files to timestamp + title (e.g. 2025-08-19t2041_invoice_car.pdf)

Fields

files: Vec<String>

One or more files to analyze and rename



Changelog

Generate a changelog starting from a given commit

Fields

commit_hash: String

The commit hash to start the changelog from



Commit

Commit modified files with AI-generated commit messages and group related changes into separate commits



Svg

Generate an SVG graphic from a textual description

Fields

prompt: Vec<String>

The prompt that describes the SVG to create



Edit

Open your editor to write the prompt



Config

Print the configuration settings loaded from the config file



SectionModels



All

Simultaneously send prompt to each provider’s default model

Fields

prompt: Vec<String>

The prompt to send to the AI models simultaneously



Google

Google

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



Gemini

  • Gemini Pro shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



GeminiFlash

  • Gemini Flash shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



GoogleImage

  • Google Gemini Image shortcut

Fields

prompt: Vec<String>

The prompt describing the image to generate



Groq

Groq

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



Llama3

  • Llama 3 shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



Cerebras

Cerebras

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



Deepseek

DeepSeek

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



Openai

OpenAI

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



Gpt5

  • GPT-5 shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



Gpt5Mini

  • GPT-5 mini shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



Gpt5Nano

  • GPT-5 nano shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



Gpt41

  • gpt-4.1 shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



Gpt41Mini

  • gpt-4.1-mini shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



Gpt41Nano

  • gpt-4.1-nano shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



O1Pro

  • o1-pro shortcut

Fields

prompt: Vec<String>

The prompt to send to the AI model



Anthropic

Anthropic

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



ClaudeOpus

  • Claude Opus

Fields

prompt: Vec<String>

The prompt to send to the AI model



ClaudeSonnet

  • Claude Sonnet

Fields

prompt: Vec<String>

The prompt to send to the AI model



ClaudeHaiku

  • Claude Haiku

Fields

prompt: Vec<String>

The prompt to send to the AI model



Xai

xAI

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



Grok

  • Grok

Fields

prompt: Vec<String>

The prompt to send to the AI model



Perplexity

Perplexity

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



Sonar

  • Sonar

Fields

prompt: Vec<String>

The prompt to send to the AI model



SonarPro

  • Sonar Pro

Fields

prompt: Vec<String>

The prompt to send to the AI model



SonarReasoning

  • Sonar Reasoning

Fields

prompt: Vec<String>

The prompt to send to the AI model



SonarReasoningPro

  • Sonar Reasoning Pro

Fields

prompt: Vec<String>

The prompt to send to the AI model



SonarDeepResearch

  • Sonar Deep Research

Fields

prompt: Vec<String>

The prompt to send to the AI model



Llamafile

Llamafile server hosted at http://localhost:8080

Fields

prompt: Vec<String>

The prompt to send to the AI model



Ollama

Ollama server hosted at http://localhost:11434

Fields

model: String
prompt: Vec<String>

The prompt to send to the AI model



SectionCoding



Bash

Use Bash development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



C

Use C development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Cpp

Use C++ development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Cs

Use C# development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Docker

Use Docker development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Elm

Use Elm development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Fish

Use Fish development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Fs

Use F# development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Gd

Use Godot and GDScript development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Git

Use Git development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Gl

Use Gleam development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Golang

Use Go development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Hs

Use Haskell development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Java

Use Java development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Js

Use JavaScript development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Kt

Use Kotlin development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Ly

Use LilyPond development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Lua

Use Lua development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Nix

Use Nix development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Oc

Use OCaml development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Php

Use PHP development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Pg

Use Postgres development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Ps

Use PureScript development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Py

Use Python development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Rb

Use Ruby development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Rs

Use Rust development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Sql

Use SQLite development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Sw

Use Swift development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Ts

Use TypeScript development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Ty

Use Typst development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Wl

Use Wolfram Language and Mathematica development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Zig

Use Zig development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



Jq

Use jq development as the prompt context

Fields

prompt: Vec<String>

The prompt to send to the AI model



SectionDatabase



Query

Query a SQLite database using natural language

Fields

database: String

Path to the SQLite database file

prompt: Vec<String>

The natural language query/question about the data

Implementations