pub enum Commands {
Show 86 variants
Fast {
prompt: Vec<String>,
},
Local {
prompt: Vec<String>,
},
Value {
prompt: Vec<String>,
},
Short {
prompt: Vec<String>,
},
Rewrite {
prompt: Vec<String>,
},
Reply {
prompt: Vec<String>,
},
Image {
prompt: Vec<String>,
},
Photo {
prompt: Vec<String>,
},
Say {
prompt: Vec<String>,
},
Transcribe {
file: String,
},
Ocr {
file: String,
},
GoogleOcr {
file: String,
},
Rename {
files: Vec<String>,
},
Changelog {
commit_hash: String,
},
Commit {},
Svg {
prompt: Vec<String>,
},
Edit {},
Config {},
SectionModels {},
All {
prompt: Vec<String>,
},
Google {
model: String,
prompt: Vec<String>,
},
Gemini {
prompt: Vec<String>,
},
GeminiFlash {
prompt: Vec<String>,
},
GoogleImage {
prompt: Vec<String>,
},
Groq {
model: String,
prompt: Vec<String>,
},
Llama3 {
prompt: Vec<String>,
},
Cerebras {
model: String,
prompt: Vec<String>,
},
Deepseek {
model: String,
prompt: Vec<String>,
},
Openai {
model: String,
prompt: Vec<String>,
},
Gpt5 {
prompt: Vec<String>,
},
Gpt5Mini {
prompt: Vec<String>,
},
Gpt5Nano {
prompt: Vec<String>,
},
Gpt41 {
prompt: Vec<String>,
},
Gpt41Mini {
prompt: Vec<String>,
},
Gpt41Nano {
prompt: Vec<String>,
},
O1Pro {
prompt: Vec<String>,
},
Anthropic {
model: String,
prompt: Vec<String>,
},
ClaudeOpus {
prompt: Vec<String>,
},
ClaudeSonnet {
prompt: Vec<String>,
},
ClaudeHaiku {
prompt: Vec<String>,
},
Xai {
model: String,
prompt: Vec<String>,
},
Grok {
prompt: Vec<String>,
},
Perplexity {
model: String,
prompt: Vec<String>,
},
Sonar {
prompt: Vec<String>,
},
SonarPro {
prompt: Vec<String>,
},
SonarReasoning {
prompt: Vec<String>,
},
SonarReasoningPro {
prompt: Vec<String>,
},
SonarDeepResearch {
prompt: Vec<String>,
},
Llamafile {
prompt: Vec<String>,
},
Ollama {
model: String,
prompt: Vec<String>,
},
SectionCoding {},
Bash {
prompt: Vec<String>,
},
C {
prompt: Vec<String>,
},
Cpp {
prompt: Vec<String>,
},
Cs {
prompt: Vec<String>,
},
Docker {
prompt: Vec<String>,
},
Elm {
prompt: Vec<String>,
},
Fish {
prompt: Vec<String>,
},
Fs {
prompt: Vec<String>,
},
Gd {
prompt: Vec<String>,
},
Git {
prompt: Vec<String>,
},
Gl {
prompt: Vec<String>,
},
Golang {
prompt: Vec<String>,
},
Hs {
prompt: Vec<String>,
},
Java {
prompt: Vec<String>,
},
Js {
prompt: Vec<String>,
},
Kt {
prompt: Vec<String>,
},
Ly {
prompt: Vec<String>,
},
Lua {
prompt: Vec<String>,
},
Nix {
prompt: Vec<String>,
},
Oc {
prompt: Vec<String>,
},
Php {
prompt: Vec<String>,
},
Pg {
prompt: Vec<String>,
},
Ps {
prompt: Vec<String>,
},
Py {
prompt: Vec<String>,
},
Rb {
prompt: Vec<String>,
},
Rs {
prompt: Vec<String>,
},
Sql {
prompt: Vec<String>,
},
Sw {
prompt: Vec<String>,
},
Ts {
prompt: Vec<String>,
},
Ty {
prompt: Vec<String>,
},
Wl {
prompt: Vec<String>,
},
Zig {
prompt: Vec<String>,
},
Jq {
prompt: Vec<String>,
},
SectionDatabase {},
Query {
database: String,
prompt: Vec<String>,
},
}Variants
Fast
Shortcut for groq openai/gpt-oss-20b
Local
Shortcut for ollama llama3.2
Value
Return only the value/answer without explanations
Short
Answer the prompt in a short, compact, and focused manner
Rewrite
Fix spelling, grammar, and wording issues in text passed via standard input
Reply
Reply to a conversation passed via standard input. Add additional reply instructions as the prompt.
Image
Generate an image using GPT-image-1.5
Photo
Generate a photorealistic image that looks like a camera photo
Say
Convert text to speech using OpenAI’s TTS model
Transcribe
Transcribe an audio file
Ocr
Extract text from an image
GoogleOcr
Extract text from an image using Google Gemini with high resolution
Rename
Analyze and rename files to timestamp + title (e.g. 2025-08-19t2041_invoice_car.pdf)
Changelog
Generate a changelog starting from a given commit
Commit
Commit modified files with AI-generated commit messages and group related changes into separate commits
Svg
Generate an SVG graphic from a textual description
Edit
Open your editor to write the prompt
Config
Print the configuration settings loaded from the config file
SectionModels
All
Simultaneously send prompt to each provider’s default model
Gemini
- Gemini Pro shortcut
GeminiFlash
- Gemini Flash shortcut
GoogleImage
- Google Gemini Image shortcut
Groq
Groq
Llama3
- Llama 3 shortcut
Cerebras
Cerebras
Deepseek
DeepSeek
Openai
OpenAI
Gpt5
- GPT-5 shortcut
Gpt5Mini
- GPT-5 mini shortcut
Gpt5Nano
- GPT-5 nano shortcut
Gpt41
- gpt-4.1 shortcut
Gpt41Mini
- gpt-4.1-mini shortcut
Gpt41Nano
- gpt-4.1-nano shortcut
O1Pro
- o1-pro shortcut
Anthropic
Anthropic
ClaudeOpus
- Claude Opus
ClaudeSonnet
- Claude Sonnet
ClaudeHaiku
- Claude Haiku
Xai
xAI
Grok
- Grok
Perplexity
Perplexity
Sonar
- Sonar
SonarPro
- Sonar Pro
SonarReasoning
- Sonar Reasoning
SonarReasoningPro
- Sonar Reasoning Pro
SonarDeepResearch
- Sonar Deep Research
Llamafile
Llamafile server hosted at http://localhost:8080
Ollama
Ollama server hosted at http://localhost:11434
SectionCoding
Bash
Use Bash development as the prompt context
C
Use C development as the prompt context
Cpp
Use C++ development as the prompt context
Cs
Use C# development as the prompt context
Docker
Use Docker development as the prompt context
Elm
Use Elm development as the prompt context
Fish
Use Fish development as the prompt context
Fs
Use F# development as the prompt context
Gd
Use Godot and GDScript development as the prompt context
Git
Use Git development as the prompt context
Gl
Use Gleam development as the prompt context
Golang
Use Go development as the prompt context
Hs
Use Haskell development as the prompt context
Java
Use Java development as the prompt context
Js
Use JavaScript development as the prompt context
Kt
Use Kotlin development as the prompt context
Ly
Use LilyPond development as the prompt context
Lua
Use Lua development as the prompt context
Nix
Use Nix development as the prompt context
Oc
Use OCaml development as the prompt context
Php
Use PHP development as the prompt context
Pg
Use Postgres development as the prompt context
Ps
Use PureScript development as the prompt context
Py
Use Python development as the prompt context
Rb
Use Ruby development as the prompt context
Rs
Use Rust development as the prompt context
Sql
Use SQLite development as the prompt context
Sw
Use Swift development as the prompt context
Ts
Use TypeScript development as the prompt context
Ty
Use Typst development as the prompt context
Wl
Use Wolfram Language and Mathematica development as the prompt context
Zig
Use Zig development as the prompt context
Jq
Use jq development as the prompt context
SectionDatabase
Query
Query a SQLite database using natural language
Implementations